==> haskell-th-utilities-0.2.1.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.1.0
id: th-utilities-0.2.1.0-KUdVr5Dfw4gKEGMdjktOQZ
key: th-utilities-0.2.1.0-KUdVr5Dfw4gKEGMdjktOQZ
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <mgsloan@gmail.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
abi: 500a7a24b3ad9a26010db2822a0b5c8a
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-utilities-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-utilities-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-utilities-0.2.1.0
hs-libraries: HSth-utilities-0.2.1.0-KUdVr5Dfw4gKEGMdjktOQZ
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 th-orphans-0.13.7-KX9FiUPbqySLIqL3I3qarI
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.1.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.1.0
id: th-utilities-0.2.1.0-2x4vYATzAQ0LS6vfuoj04B
key: th-utilities-0.2.1.0-2x4vYATzAQ0LS6vfuoj04B
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <mgsloan@gmail.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
abi: f760d3eefcbec4e2a5c5a02e64b9d5f6
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-utilities-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-utilities-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-utilities-0.2.1.0
hs-libraries: HSth-utilities-0.2.1.0-2x4vYATzAQ0LS6vfuoj04B
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 th-orphans-0.13.7-2ePq3BJJT4e6MJsnWt98P0
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
